@@ -22,7 +22,7 @@ def code_block(language: str, code: str, **options: str) -> str:
         The formatted code block.
     """
     opts = " ".join(f'{opt_name}="{opt_value}"' for opt_name, opt_value in options.items())
-    return f"```{language} {opts}\n{code}\n```"
+    return f"````````{language} {opts}\n{code}\n````````"
 
 
 def tabbed(*tabs: tuple[str, str]) -> str:
@@ -43,7 +43,15 @@ def tabbed(*tabs: tuple[str, str]) -> str:
     return "\n".join(parts)
 
 
-def add_source(*, source: str, location: str, output: str, language: str, tabs: tuple[str, str], **extra: str) -> str:
+def add_source(  # noqa: WPS212
+    *,
+    source: str,
+    location: str,
+    output: str,
+    language: str,
+    tabs: tuple[str, str],
+    **extra: str,
+) -> str:
     """Add source code block to the output.
 
     Parameters:
@@ -68,6 +76,10 @@ def add_source(*, source: str, location: str, output: str, language: str, tabs:
         return source_block + "\n\n" + output
     if location == "below":
         return output + "\n\n" + source_block
+    if location == "material-block":
+        # TODO: remove style once margins are fixed in Material for MkDocs
+        style = 'style="margin-top: 0;"'
+        return source_block + f'\n\n<div class="result" {style} markdown="1" >\n\n{output}\n\n</div>'
 
     source_tab_title, result_tab_title = tabs
     if location == "tabbed-left":
@@ -110,29 +122,31 @@ class _IdPrependingTreeprocessor(Treeprocessor):
                     el.set("for", self.id_prefix + for_attr)
 
 
+def _mimic(md: Markdown) -> Markdown:
+    new_md = Markdown()  # noqa: WPS442
+    new_md.registerExtensions(md.registeredExtensions + ["tables", "md_in_html"], {})
+    new_md.treeprocessors.register(
+        _IdPrependingTreeprocessor(md, ""),
+        _IdPrependingTreeprocessor.name,
+        priority=4,  # right after 'toc' (needed because that extension adds ids to headers)
+    )
+    return new_md
+
+
 class _MarkdownConverter:
     """Helper class to avoid breaking the original Markdown instance state."""
 
     def __init__(self) -> None:  # noqa: D107
-        self.md: Markdown = None  # type: ignore[assignment]
-        self.counter: int = 0
+        self._md_ref: Markdown = None  # type: ignore[assignment]
+        self._md_stack: list[Markdown] = []
+        self._counter: int = 0
+        self._level: int = 0
 
-    def mimic(self, md: Markdown) -> None:
-        """Mimic the passed Markdown instance by registering the same extensions.
+    def setup(self, md: Markdown) -> None:
+        if not self._md_ref:
+            self._md_ref = md
 
-        Parameters:
-            md: A Markdown instance.
-        """
-        if self.md is None:
-            self.md = Markdown()  # noqa: WPS442
-            self.md.registerExtensions(md.registeredExtensions + ["pymdownx.extra"], {})
-            self.md.treeprocessors.register(
-                _IdPrependingTreeprocessor(md, ""),
-                _IdPrependingTreeprocessor.name,
-                priority=4,  # right after 'toc' (needed because that extension adds ids to headers)
-            )
-
-    def convert(self, text: str, stash: dict[str, str] | None = None) -> Markup:
+    def convert(self, text: str, stash: dict[str, str]) -> Markup:
         """Convert Markdown text to safe HTML.
 
         Parameters:
@@ -142,18 +156,34 @@ class _MarkdownConverter:
         Returns:
             Safe HTML.
         """
-        self.md.treeprocessors[_IdPrependingTreeprocessor.name].id_prefix = f"exec-{self.counter}--"
-        self.counter += 1
+        # store current md instance
+        md = self._md
+        self._level += 1
+
+        # prepare for conversion
+        md.treeprocessors[_IdPrependingTreeprocessor.name].id_prefix = f"exec-{self._counter}--"
+        self._counter += 1
 
         try:  # noqa: WPS501
-            converted = self.md.convert(text)
+            converted = md.convert(text)
         finally:
-            self.md.treeprocessors[_IdPrependingTreeprocessor.name].id_prefix = ""
-        if stash:
-            for placeholder, stashed in stash.items():
-                converted = converted.replace(placeholder, stashed)
+            self._level -= 1
+            md.treeprocessors[_IdPrependingTreeprocessor.name].id_prefix = ""
+
+        # restore html from stash
+        for placeholder, stashed in stash.items():
+            converted = converted.replace(placeholder, stashed)
+
         return Markup(converted)
 
+    @property
+    def _md(self) -> Markdown:
+        try:
+            return self._md_stack[self._level]
+        except IndexError:
+            self._md_stack.append(_mimic(self._md_ref))
+            return self._md
+
 
 # provide a singleton
 markdown = _MarkdownConverter()
